# Kraken CI Client

This is a client tool for accessing Kraken CI server, https://kraken.ci.


<!-- ABOUT THE PROJECT -->
## About Kraken CI

![Kraken CI Results Page](https://kraken.ci/img/slide-branch-results.png)

Kraken CI is a modern, open-source, on-premise CI/CD system
that is highly scalable and focused on testing.

More information can be found on https://kraken.ci


<!-- GETTING STARTED -->
## Getting Started

Quick start guide is here: https://kraken.ci/docs/quick-start

Full installation manual: https://kraken.ci/docs/installation

And here is developers guide: https://kraken.ci/docs/dev-guide


<!-- USAGE EXAMPLES -->
## Usage

Guides can be found here: https://kraken.ci/docs/guide-intro

Demo site is available here: https://lab.kraken.ci/


<!-- ROADMAP -->
## Roadmap

See the [open issues](https://github.com/kraken-ci/kraken/issues) for a list of proposed features (and known issues).


<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

Details on https://kraken.ci/docs/contrib-kraken


<!-- LICENSE -->
## License

Distributed under the Apache 2.0 License. See `LICENSE` for more information.


<!-- CONTACT -->
## Contact

Michal Nowikowski - godfryd@gmail.com

Project Link: [https://kraken.ci](https://kraken.ci)
